)]}'
{
  "commit": "3bdc2f3abf0f9cffc8f4e294ef22a23b82e88415",
  "tree": "7d3a411585777e41b530a8f7616c296591966c7f",
  "parents": [
    "2f73efa97136a6d4a602a94e87d2a948240e7e8a"
  ],
  "author": {
    "name": "Ilya Tocar",
    "email": "ilya.tocar@intel.com",
    "time": "Fri Apr 14 13:53:40 2017 -0500"
  },
  "committer": {
    "name": "Ilya Tocar",
    "email": "ilya.tocar@intel.com",
    "time": "Thu Jun 01 15:46:16 2017 +0000"
  },
  "message": "cmd/compile/internal/gc: speed-up small array comparison\n\nCurrently we inline array comparisons for arrays with at most 4 elements.\nCompare arrays with small size, but more than 4 elements (e. g. [16]byte)\nwith larger compares. This provides very slightly smaller binaries,\nand results in faster code.\n\nArrayEqual-6  7.41ns ± 0%  3.17ns ± 0%  -57.15%  (p\u003d0.000 n\u003d10+10)\n\nFor go tool:\nglobal text (code) \u003d -559 bytes (-0.014566%)\n\nThis also helps mapaccess1_faststr, and maps in general:\n\nMapDelete/Str/1-6               195ns ± 1%     186ns ± 2%   -4.47%  (p\u003d0.000 n\u003d10+10)\nMapDelete/Str/2-6               211ns ± 1%     177ns ± 1%  -16.01%  (p\u003d0.000 n\u003d10+10)\nMapDelete/Str/4-6               225ns ± 1%     183ns ± 1%  -18.49%  (p\u003d0.000 n\u003d8+10)\nMapStringKeysEight_16-6        31.3ns ± 0%    28.6ns ± 0%   -8.63%  (p\u003d0.000 n\u003d6+9)\nMapStringKeysEight_32-6        29.2ns ± 0%    27.6ns ± 0%   -5.45%  (p\u003d0.000 n\u003d10+10)\nMapStringKeysEight_64-6        29.1ns ± 1%    27.5ns ± 0%   -5.46%  (p\u003d0.000 n\u003d10+10)\nMapStringKeysEight_1M-6        29.1ns ± 1%    27.6ns ± 0%   -5.49%  (p\u003d0.000 n\u003d10+10)\n\nChange-Id: I9ec98e41b233031e0e96c4e13d86a324f628ed4a\nReviewed-on: https://go-review.googlesource.com/40771\nRun-TryBot: Ilya Tocar \u003cilya.tocar@intel.com\u003e\nTryBot-Result: Gobot Gobot \u003cgobot@golang.org\u003e\nReviewed-by: Keith Randall \u003ckhr@golang.org\u003e\n",
  "tree_diff": [
    {
      "type": "modify",
      "old_id": "bac09ef295784eb5c2d9088fc2782c544cbe72b9",
      "old_mode": 33188,
      "old_path": "src/cmd/compile/internal/gc/asm_test.go",
      "new_id": "221b8497f15984d834118d81045eb2a3bd1d73dd",
      "new_mode": 33188,
      "new_path": "src/cmd/compile/internal/gc/asm_test.go"
    },
    {
      "type": "modify",
      "old_id": "557293b9f01bcdf38969e5a12b3836f08f6db736",
      "old_mode": 33188,
      "old_path": "src/cmd/compile/internal/gc/walk.go",
      "new_id": "15108e6e5737a50fdf8daf3a1f2b29a15284ce09",
      "new_mode": 33188,
      "new_path": "src/cmd/compile/internal/gc/walk.go"
    },
    {
      "type": "modify",
      "old_id": "ebba001d46bd4387110caea5f4e73566eae061ed",
      "old_mode": 33188,
      "old_path": "src/runtime/hashmap_fast.go",
      "new_id": "1f9b313219c52c6a31696c2970219cb155d2ca44",
      "new_mode": 33188,
      "new_path": "src/runtime/hashmap_fast.go"
    }
  ]
}
